@@ -30,17 +30,24 @@ class Csv(Base):
     def start(self, **kwargs):
         """Create csvstream and associated file descriptor."""
         super(Csv, self).start(**kwargs)
+        self._start(**kwargs)
+
+    def _start(self, **kwargs):
         self.GETARGS["field_null"] = True
         self.GETARGS["field_flatten"] = True
         self.GETARGS["field_join"] = True
-        self.GETARGS["field_titles"] = True
+        if self.GETARGS.get("field_titles", None) is None:
+            self.GETARGS["field_titles"] = True
 
         restval = self.GETARGS.get("csv_key_miss", None)
         dialect = self.get_csv_dialect()
         quote = self.get_csv_quote()
 
         final = self.schemas_final(flat=True)
-        titles = [x["column_title"] for x in final]
+        if self.GETARGS["field_titles"]:
+            titles = [x["column_title"] for x in final]
+        else:
+            titles = [x["name_qual"] for x in final]
 
         self.open_fd()
         self._fd.write(codecs.BOM_UTF8.decode("utf-8"))
@@ -71,15 +78,24 @@ class Csv(Base):
         export_schema = self.GETARGS.get("export_schema", True)
 
         if export_schema:
-            titles = [x["column_title"] for x in final]
-            names = [x["name_qual"] for x in final]
-            types = [x["type_norm"] for x in final]
-
-            self._stream.writerow(dict(zip(titles, names)))
-            self._stream.writerow(dict(zip(titles, types)))
+            if self.GETARGS["field_titles"]:
+                titles = [x["column_title"] for x in final]
+                names = [x["name_qual"] for x in final]
+                types = [x["type_norm"] for x in final]
+                self._stream.writerow(dict(zip(titles, names)))
+                self._stream.writerow(dict(zip(titles, types)))
+            else:
+                titles = [x["column_title"] for x in final]
+                names = [x["name_qual"] for x in final]
+                types = [x["type_norm"] for x in final]
+                self._stream.writerow(dict(zip(names, titles)))
+                self._stream.writerow(dict(zip(names, types)))
 
     def stop(self, **kwargs):
         """Close dictwriter and associated file descriptor."""
         super(Csv, self).stop(**kwargs)
+        self._stop(**kwargs)
+
+    def _stop(self, **kwargs):
         self._fd.write("\n")
         self.close_fd()
