@@ -4,16 +4,15 @@ import os
 
 import dotenv
 import pytest
+
 from axonius_api_client.api import enforcements, system
 from axonius_api_client.api.adapters import Adapters
 from axonius_api_client.api.adapters.cnx import Cnx
-from axonius_api_client.api.assets import (Devices, Users, fields, labels,
-                                           saved_query)
+from axonius_api_client.api.assets import Devices, Users, fields, labels, saved_query
 from axonius_api_client.constants import CSV_ADAPTER, DEFAULT_NODE
 
 from .meta import CSV_FILECONTENT_STR, CSV_FILENAME, QUERIES
-from .utils import (check_apiobj, check_apiobj_children, check_apiobj_xref,
-                    get_auth)
+from .utils import check_apiobj, check_apiobj_children, check_apiobj_xref, get_auth
 
 dotenv.load_dotenv()
 
@@ -85,6 +84,7 @@ def api_devices(request):
     obj.TEST_DATA["cb_assets_query"] = cb_assets_query
     obj.TEST_DATA["field_complexes"] = obj.fields_default + [field_complex]
     obj.TEST_DATA["field_main"] = obj.FIELD_HOSTNAME
+    obj.TEST_DATA["has_complex"] = True
     return obj
 
 
@@ -117,6 +117,8 @@ def api_users(request):
     obj.TEST_DATA["cb_assets_query"] = cb_assets_query
     obj.TEST_DATA["field_complexes"] = obj.fields_default
     obj.TEST_DATA["field_main"] = obj.FIELD_USERNAME
+    # demo systems have no complex fields for users anymore as of around 3.2
+    obj.TEST_DATA["has_complex"] = False
     return obj
 
 
